#
# elongateTrpLeader.bash
# distributed with MC-Flashfold.zip
# under /doc/examples/elongation/
# 
# invoque using a line like so in a terminal: bash elongateTrpLeader.bash
# or cut and paste the contents of this file to the command line
# outputs an html and svg files showing dot plots and arcs plots for 6 lenghts of 
# the trp operon leader sequence.
#
# If loaded in the chrome Internet browser the html file will correctly display the dotplots
# These plots show that (a) the anti-terminator loop dominates the folds at lenghts about
# 115nt to 125nt and thereafter is swamped by the domination of the terminator loop.
#
# Paul Dallaire
# Jan 21, 2015
#


#this is the trp operon leader sequence
seq=AGUUCACGUAAAAAGGGUAUCGACAAUGAAAGCAAUUUUCGUACUGAAAGGUUGGUGGCGCACUUCCUGAAACGGGCAGUGUAUUCACCAUGCGUAAAGCAAUCAGAUACCCAGCCCGCCUAAUGAGCGGGCU

#parameters for mcff and db2cm
depth=1000; 

#parameters for db2cm
sensitivity=1; 
imgSize=0.09; 

#subsequence lenghts specification
start=113; 
step=5; 
end=$((${#seq} + step - 1)); 

#silently cleanup svg files from previous runs if any
rm *.svg 2> /dev/null

#this html file will wrap the resulting images
HTMLFile=elongatingTrpLeaderDotPlots.html

#html trivial header line to new version of hte html file
echo '<html>' > $HTMLFile
echo 'this file is best viewed with the Chrome Internet browser<br>' >> $HTMLFile

#repeat for all subsequences required  
for stop in $(seq $start $step $end); do 

    #cap stop to actual str ing length
    if [[ $stop -lt ${#seq} ]]; then
	actualStop=$stop;
    else
	actualStop=${#seq}
    fi

    #set the actual sequence to use
    shortSeq=${seq:0:$stop}; 

    imgFileNamePrefix=trpLeaderSubseq

    #compute the secondary structures (and a few more so that we get a clean dot bracket)
    mcff -ft $((depth * 2)) -n seqname_len$actualStop -s $shortSeq -v > ${imgFileNamePrefix}.$actualStop.mcff; 

    #generatet the dot plot/arcs plot image
    db2cm -f  ${imgFileNamePrefix}.$actualStop.mcff -xdb $depth -b 1 -sensitivity $sensitivity -size $imgSize; 

    #add this image to the html file
    echo "<img src=${imgFileNamePrefix}.$actualStop.mcff.svg>" >> $HTMLFile

    #remove the predictions from the hard drive because they are not needed anymore
    rm ${imgFileNamePrefix}.$actualStop.mcff; 

done; #that's it for this subsequence

#add trivial footer to html file
echo '</html>' >> $HTMLFile
